## Copyright 2012 Sebastian Gibb
## <mail@sebastiangibb.de>
##
## This file is part of MALDIquant for R and related languages.
##
## MALDIquant is free software: you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation, either version 3 of the License, or
## (at your option) any later version.
##
## MALDIquant is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with MALDIquant. If not, see <http://www.gnu.org/licenses/>

## calibrate
##  calibrate intensityMatrix
##
## params:
##  x: a numeric matrix (generated by MALDIquant::intensityMatrix
##      rows: samples; cols: features
##
## returns:
##  a calibrated numeric matrix
##
setMethod(f="calibrate",
    signature=signature(x="matrix"),
    definition=function(x, ...) {

    ## create "reference" spectrum/peak list
    r <- apply(x, 2, median, na.rm=TRUE);

    ## estimate scale factor
    s <- apply(x, 1, function(y)median(y/r, na.rm=TRUE));

    ## scale matrix
    x <- apply(x, 2, function(y)y/s);

    ## add scale attribute
    attr(x, "scale") <- s;

    return(x);
});

